@@ -150,8 +150,8 @@ export const tests: [
                     namespace: null,
                     action: "equals",
                     name: "id",
-                    value: " ",
                     ignoreCase: false,
+                    value: " ",
                 },
                 {
                     type: "child",
@@ -174,8 +174,8 @@ export const tests: [
                     namespace: null,
                     name: "class",
                     action: "element",
-                    value: " ",
                     ignoreCase: false,
+                    value: " ",
                 },
             ],
         ],
@@ -190,8 +190,8 @@ export const tests: [
                     namespace: null,
                     name: "class",
                     action: "element",
-                    value: "m™²³",
                     ignoreCase: false,
+                    value: "m™²³",
                 },
             ],
         ],
@@ -232,8 +232,8 @@ export const tests: [
                     namespace: null,
                     action: "equals",
                     name: "id",
-                    value: "&B",
                     ignoreCase: false,
+                    value: "&B",
                 },
             ],
         ],
@@ -249,9 +249,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "name",
+                    ignoreCase: false,
                     action: "start",
                     value: "foo[",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -265,9 +265,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "name",
+                    ignoreCase: false,
                     action: "start",
                     value: "foo[bar]",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -281,9 +281,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "name",
+                    ignoreCase: false,
                     action: "end",
                     value: "[bar]",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -297,9 +297,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "href",
+                    ignoreCase: false,
                     action: "any",
                     value: "google",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -313,9 +313,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "value",
+                    ignoreCase: false,
                     action: "equals",
                     value: "\nsome text\n",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -329,9 +329,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "name",
+                    ignoreCase: false,
                     action: "equals",
                     value: "foo.baz",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -345,9 +345,9 @@ export const tests: [
                     type: "attribute",
                     namespace: null,
                     name: "name",
+                    ignoreCase: false,
                     action: "equals",
                     value: "foo[bar]",
-                    ignoreCase: false,
                 },
             ],
         ],
@@ -396,8 +396,8 @@ export const tests: [
                     namespace: null,
                     action: "equals",
                     name: "id",
-                    value: ".identifier",
                     ignoreCase: false,
+                    value: ".identifier",
                 },
             ],
         ],
@@ -458,6 +458,27 @@ export const tests: [
         ],
         "pseudo selector with data",
     ],
+    [
+        ":where(a)",
+        [
+            [
+                {
+                    type: "pseudo",
+                    name: "where",
+                    data: [
+                        [
+                            {
+                                type: "tag",
+                                namespace: null,
+                                name: "a",
+                            },
+                        ],
+                    ],
+                },
+            ],
+        ],
+        "pseudo selector with data",
+    ],
     [
         ':contains("(a((foo\\\\\\))))")',
         [
@@ -562,8 +583,8 @@ export const tests: [
                     namespace: null,
                     action: "equals",
                     name: "id",
-                    value: "types_all",
                     ignoreCase: false,
+                    value: "types_all",
                 },
             ],
         ],
@@ -790,17 +811,34 @@ export const tests: [
                 },
                 {
                     action: "exists",
-                    ignoreCase: false,
                     name: "baR",
                     type: "attribute",
                     namespace: null,
                     value: "",
+                    ignoreCase: null,
                 },
             ],
         ],
         "XML mode",
         { xmlMode: true },
     ],
+    [
+        "#myID",
+        [
+            [
+                {
+                    action: "equals",
+                    name: "id",
+                    type: "attribute",
+                    namespace: null,
+                    value: "myID",
+                    ignoreCase: null,
+                },
+            ],
+        ],
+        "IDs in XML mode",
+        { xmlMode: true },
+    ],
     [
         "fOo[baR]",
         [
@@ -812,11 +850,11 @@ export const tests: [
                 },
                 {
                     action: "exists",
-                    ignoreCase: false,
                     name: "baR",
                     type: "attribute",
                     namespace: null,
                     value: "",
+                    ignoreCase: false,
                 },
             ],
         ],
@@ -834,11 +872,11 @@ export const tests: [
                 },
                 {
                     action: "exists",
-                    ignoreCase: false,
                     name: "bar",
                     type: "attribute",
                     namespace: null,
                     value: "",
+                    ignoreCase: false,
                 },
             ],
         ],
@@ -873,6 +911,19 @@ export const tests: [
         ],
         "star tag namespace",
     ],
+    [
+        "|bar",
+        [
+            [
+                {
+                    name: "bar",
+                    type: "tag",
+                    namespace: "",
+                },
+            ],
+        ],
+        "without namespace",
+    ],
     [
         "*|*",
         [
@@ -891,16 +942,32 @@ export const tests: [
             [
                 {
                     action: "exists",
-                    ignoreCase: false,
                     name: "bar",
                     type: "attribute",
                     namespace: "foo",
                     value: "",
+                    ignoreCase: false,
                 },
             ],
         ],
         "basic attribute namespace, existential",
     ],
+    [
+        "[|bar]",
+        [
+            [
+                {
+                    action: "exists",
+                    name: "bar",
+                    type: "attribute",
+                    namespace: "",
+                    value: "",
+                    ignoreCase: false,
+                },
+            ],
+        ],
+        "without namespace, existential",
+    ],
     [
         "[foo|bar='baz' i]",
         [
@@ -933,4 +1000,20 @@ export const tests: [
         ],
         "star attribute namespace",
     ],
+    [
+        "[type='a' S]",
+        [
+            [
+                {
+                    action: "equals",
+                    ignoreCase: false,
+                    name: "type",
+                    type: "attribute",
+                    value: "a",
+                    namespace: null,
+                },
+            ],
+        ],
+        "case-sensitive attribute selector",
+    ],
 ];
